@@ -360,7 +360,7 @@ pango_font_description_set_size (PangoFontDescription *desc,
  * @desc: a #PangoFontDescription
  * 
  * Gets the size field of a font description.
- * See pango_font_description_get_size().
+ * See pango_font_description_set_size().
  * 
  * Return value: the size field for the font description in points or device units.
  *   You must call pango_font_description_get_size_is_absolute()
@@ -1210,7 +1210,7 @@ pango_font_get_glyph_extents  (PangoFont      *font,
 			       PangoRectangle *ink_rect,
 			       PangoRectangle *logical_rect)
 {
-  if (G_UNLIKELY (!PANGO_IS_FONT (font)))
+  if (G_UNLIKELY (!font))
     {
       
       if (!_pango_warning_history.get_glyph_extents)
