@@ -26,7 +26,7 @@
 #include <gmodule.h>
 #include "pango-break.h"
 #include "pango-context.h"
-#include "pango-utils.h"
+#include "pango-impl-utils.h"
 #include "pango-engine.h"
 #include "pango-enum-types.h"
 
@@ -37,12 +37,12 @@
 #endif
 #include <glib/gprintf.h>
 
-#if USE_LA_MODULES
+#ifdef USE_LA_MODULES
 #define SOEXT ".la"
 #else
 #define SOEXT ("." G_MODULE_SUFFIX)
 #endif
-#define SOEXT_LEN (strlen (SOEXT))
+#define SOEXT_LEN ((int) strlen (SOEXT))
 
 static gboolean
 string_needs_escape (const char *str)
